fermi_velocity — PyProcar 6.2.1 documentation

Skip to main content
`Ctrl`+`K`

# fermi_velocity

property ElectronicBandStructure.fermi_velocity

  fermi_velocity is a numpy array that stores each fermi_velocity a list that corresponds to the self.kpoints Shape = [n_kpoints,3,n_bands], where the second dimension represents d/dx,d/dy,d/dz

  Returns:

    np.ndarray – fermi_velocity is a numpy array that stores each fermi_velocity in a list that corresponds to the self.kpoints Shape = [n_kpoints,3,n_bands], where the second dimension represents d/dx,d/dy,d/dz